@@ -11,5 +11,5 @@ class HyperOptAlgoWrapper():
         self.algorithm = HyperOptSearch(
             search_space,
             metric=metric,
-            mode=mode)
+            mode=mode, **args)
         return self.algorithm
\ No newline at end of file
