@@ -36,6 +36,7 @@ class GridHandler():
                             default='grid')
         parser.add_argument('-p','--search_points', help='json file containing a list of '
                             'search points to evaluate (for non-idds jobs only)', default=None)
+        parser.add_argument('-d','--debug', action='store_true', help='debug mode')        
         return parser
 
     def run_parser(self):
@@ -50,16 +51,17 @@ class GridHandler():
                     time=args.time,
                     search_points = args.search_points,
                     mode=args.mode,
+                    debug=args.debug,
                     extra=extra)
     
     @staticmethod
-    def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid', extra=[]):
+    def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid', debug=False, extra=[]):
         config = GridHandler.preprocess_config(config_input)
         if mode == 'grid':
             GridHandler.submit_grid(config, n_jobs=n_jobs, site=site,
-                                    time=time, search_points=search_points, extra=extra)
+                                    time=time, search_points=search_points, debug=debug, extra=extra)
         elif mode == 'idds':
-            GridHandler.submit_idds(config, n_jobs=n_jobs, site=site, extra=extra)
+            GridHandler.submit_idds(config, n_jobs=n_jobs, site=site, debug=debug, extra=extra)
         else:
             raise ValueError('Unknown job submission mode: {}'.format(mode))
             
@@ -77,7 +79,7 @@ class GridHandler():
         return config
         
     @staticmethod
-    def submit_idds(config, n_jobs=1, site=None, extra=[]):
+    def submit_idds(config, n_jobs=1, site=None, debug=False, extra=[]):
         project_path = helper.get_project_path(config['project_name'])
         print('INFO: Submitting {} idds grid job(s)'.format(n_jobs))
         with tempfile.TemporaryDirectory() as tmpdirname:
@@ -94,11 +96,17 @@ class GridHandler():
                                                site=site,
                                                extra=extra)
             with helper.cd(project_path):
-                # submit jobs
+                if debug:
+                    print('INFO: iDDS configuration is')
+                    tatble = stylus.create_table(idds_config, ['Attribute', 'Value'], indexed=False)
+                    print(table)
+                    # submit jobs
+                    print('INFO: The idds command is ')
+                    print('\t{}'.format(command))
                 for _ in range(n_jobs):
                     os.system(command)
     @staticmethod
-    def submit_grid(config, n_jobs=1, site=None, time=-1, search_points=None, extra=[]):
+    def submit_grid(config, n_jobs=1, site=None, time=-1, search_points=None, debug=False, extra=[]):
         project_path = helper.get_project_path(config['project_name'])
         print('INFO: Submitting {} grid job(s)'.format(n_jobs))
         command = GridHandler.format_grid_command(config, site=site,
@@ -108,6 +116,9 @@ class GridHandler():
         with helper.cd(project_path):
             # submit jobs
             for _ in range(n_jobs):
+                if debug:
+                    print('INFO: The prun command is ')
+                    print('{}'.format(command))                
                 os.system(command)
                 
     @staticmethod
